@@ -10,10 +10,11 @@
 #undef HAVE_LDAP
 #undef HAVE_MDB
 #undef HAVE_ORACLE
+#undef HAVE_PRIMEBASE
 #undef HAVE_TDS
 #undef HAVE_SYBASE
 #undef SYBASE_DEBUG
 #undef HAVE_POSTGRES
 #undef HAVE_CAMEL
-#undef USING_GCONF
-#undef USING_OAF
+
+#undef HAVE_PERL
