@@ -21,14 +21,16 @@
 
 #include "gdaIncludes.h"
 
-class gdaBatch {
-	public:
-		gdaBatch();
-		gdaBatch(Gda_Batch *a);
-		~gdaBatch();
+namespace gda {
 
-		Gda_Batch *getCStruct();
-		void setCStruct(Gda_Batch *job);
+class Batch {
+	public:
+		Batch();
+		Batch(GdaBatch *a);
+		~Batch();
+
+		GdaBatch *getCStruct();
+		void setCStruct(GdaBatch *job);
 
 		gboolean loadFile(const gchar *filename, gboolean clean);
 		void addCommand(const gchar *cmd);
@@ -38,14 +40,16 @@ class gdaBatch {
 		void stop();
 		gboolean isRunning();
 
-		gdaConnection* getConnection();
-		void setConnection(gdaConnection *cnc);
+		Connection* getConnection();
+		void setConnection(Connection *cnc);
 		gboolean getTransactionMode();
 		void setTransactionMode(gboolean mode);
 
 	private:
-		Gda_Batch* _gda_batch;
-		gdaConnection *cnc;
+		GdaBatch* _gda_batch;
+		Connection *cnc;
+
+};
 
 };
 
