@@ -21,29 +21,33 @@
 
 #include "gdaIncludes.h"
 
-class gdaCommand {
-	public:
-		gdaCommand();
-		gdaCommand(Gda_Command *cmd);
-		~gdaCommand();
+namespace gda {
 
-		Gda_Command *getCStruct();
-		void setCStruct(Gda_Command *cmd);
+class Command {
+	public:
+		Command();
+		Command(GdaCommand *cmd);
+		~Command();
+
+		GdaCommand *getCStruct();
+		void setCStruct(GdaCommand *cmd);
 		
-		gdaConnection *getConnection();
-		gint setConnection(gdaConnection *a);
+		Connection *getConnection();
+		gint setConnection(Connection *a);
 		gchar *getText();
 		void setText(gchar *text);
 		GDA_CommandType getCmdType();
 		void setCmdType(GDA_CommandType type);
-		gdaRecordset *execute(gulong* reccount, gulong flags);
-		void createParameter(gchar* name, GDA_ParameterDirection inout, gdaValue *value);
+		Recordset *execute(gulong* reccount, gulong flags);
+		void createParameter(gchar* name, GDA_ParameterDirection inout, Value *value);
 		glong getTimeout();
 		void setTimeout(glong timeout);
 
 	private:
-		gdaConnection *cnc;
-		Gda_Command* _gda_command;
+		Connection *cnc;
+		GdaCommand* _gda_command;
+};
+
 };
 
 #endif
