@@ -21,14 +21,16 @@
 
 #include "gdaIncludes.h"
 
-class gdaError {
-	public:
-		gdaError();
-		gdaError(Gda_Error *e);
-		~gdaError();
+namespace gda {
 
-		Gda_Error *getCStruct();
-		void setCStruct(Gda_Error *e);
+class Error {
+	public:
+		Error();
+		Error(GdaError *e);
+		~Error();
+
+		GdaError *getCStruct();
+		void setCStruct(GdaError *e);
 		
 		const gchar* description();
 		const glong number();
@@ -39,7 +41,9 @@ class gdaError {
 		const gchar* realcommand();
 
 	private:
-		Gda_Error* _gda_error;
+		GdaError* _gda_error;
+};
+
 };
 
 #endif
