@@ -21,11 +21,13 @@
 
 #include "gdaIncludes.h"
 
-class gdaErrorList {
+namespace gda {
+
+class ErrorList {
 	public:
-		gdaErrorList(CORBA_Environment* ev);
-		gdaErrorList(GList *errorList);
-		~gdaErrorList();
+		ErrorList(CORBA_Environment* ev);
+		ErrorList(GList *errorList);
+		~ErrorList();
 		
 		GList *getCStruct();
 		void setCStruct(GList *errorList);
@@ -34,6 +36,8 @@ class gdaErrorList {
 	private:
 		GList* _errors;
 };
-							     
+
+};
+
 #endif  
   
