@@ -21,6 +21,10 @@
 #include "config.h"
 #include "gda-recordset.h"
 
+#ifndef HAVE_GOBJECT
+#  include <gtk/gtksignal.h>
+#endif
+
 enum {
 	RECORDSET_ERROR,
 	RECORDSET_EOF,
@@ -32,18 +36,19 @@ enum {
 static gint gda_recordset_signals[LAST_SIGNAL] = {0, };
 
 #ifdef HAVE_GOBJECT
-static void   gda_recordset_class_init (Gda_RecordsetClass *klass,
+static void   gda_recordset_class_init (GdaRecordsetClass *klass,
                                         gpointer data);
-static void   gda_recordset_init       (Gda_Recordset *rs,
-                                        Gda_RecordsetClass *klass);
+static void   gda_recordset_init       (GdaRecordset *rs,
+                                        GdaRecordsetClass *klass);
 #else
-static void   gda_recordset_class_init (Gda_RecordsetClass *);
-static void   gda_recordset_init       (Gda_Recordset *);
+static void   gda_recordset_class_init (GdaRecordsetClass *);
+static void   gda_recordset_init       (GdaRecordset *);
+static void   gda_recordset_destroy    (GtkObject *object, gpointer user_data);
 #endif
 
-static void   gda_recordset_real_error (Gda_Recordset *, GList *);
-static gulong fetch_and_store          (Gda_Recordset* rs, gint count, gpointer bookmark);
-static gulong fetch_and_dont_store     (Gda_Recordset* rs, gint count, gpointer bookmark);
+static void   gda_recordset_real_error (GdaRecordset *, GList *);
+static gulong fetch_and_store          (GdaRecordset* rs, gint count, gpointer bookmark);
+static gulong fetch_and_dont_store     (GdaRecordset* rs, gint count, gpointer bookmark);
 
 /* per default there's no upper limit on the number of rows which can
  * be fetched from the data source
@@ -54,8 +59,9 @@ static gulong fetch_and_dont_store     (Gda_Recordset* rs, gint count, gpointer
 #define GDA_DEFAULT_CACHESIZE 64
 
 static void
-gda_recordset_real_error (Gda_Recordset *rs, GList *error_list) {
-	Gda_Connection *cnc;
+gda_recordset_real_error (GdaRecordset *rs, GList *error_list)
+{
+	GdaConnection *cnc;
 	
 	g_return_if_fail(IS_GDA_CONNECTION(cnc));
 	
@@ -66,36 +72,38 @@ gda_recordset_real_error (Gda_Recordset *rs, GList *error_list) {
 
 #ifdef HAVE_GOBJECT
 GType
-gda_recordset_get_type (void) {
+gda_recordset_get_type (void)
+{
 	static GType type = 0;
 	
 	if (!type) {
 		GTypeInfo info = {
-			sizeof (Gda_RecordsetClass),               /* class_size */
+			sizeof (GdaRecordsetClass),               /* class_size */
 			NULL,                                      /* base_init */
 			NULL,                                      /* base_finalize */
 			(GClassInitFunc) gda_recordset_class_init, /* class_init */
 			NULL,                                      /* class_finalize */
 			NULL,                                      /* class_data */
-			sizeof (Gda_Recordset),                    /* instance_size */
+			sizeof (GdaRecordset),                    /* instance_size */
 			0,                                         /* n_preallocs */
 			(GInstanceInitFunc) gda_recordset_init,    /* instance_init */
 			NULL,                                      /* value_table */
 		};
-		type = g_type_register_static (G_TYPE_OBJECT, "Gda_Recordset", &info);
+		type = g_type_register_static (G_TYPE_OBJECT, "GdaRecordset", &info, 0);
 	}
 	return type;
 }
 #else
 guint
-gda_recordset_get_type (void) {
+gda_recordset_get_type (void)
+{
 	static guint gda_recordset_type = 0;
 	
 	if (!gda_recordset_type) {
 		GtkTypeInfo gda_recordset_info = {
 			"GdaRecordset",
-			sizeof(Gda_Recordset),
-			sizeof(Gda_RecordsetClass),
+			sizeof(GdaRecordset),
+			sizeof(GdaRecordsetClass),
 			(GtkClassInitFunc) gda_recordset_class_init,
 			(GtkObjectInitFunc) gda_recordset_init,
 			(GtkArgSetFunc) NULL,
@@ -109,7 +117,8 @@ gda_recordset_get_type (void) {
 
 #ifdef HAVE_GOBJECT
 static void
-gda_recordset_class_init (Gda_RecordsetClass *klass, gpointer data) {
+gda_recordset_class_init (GdaRecordsetClass *klass, gpointer data)
+{
 	/* FIXME: No signals in GObject yet */
 	klass->error = gda_recordset_real_error;
 	klass->eof = NULL;
@@ -122,14 +131,15 @@ typedef void (*GtkSignal_NONE__INT_POINTER)(GtkObject,
                                             gpointer user_data);
 
 static void
-gda_recordset_class_init (Gda_RecordsetClass *klass) {
+gda_recordset_class_init (GdaRecordsetClass *klass)
+{
 	GtkObjectClass* object_class = (GtkObjectClass *) klass;
-	
+
 	gda_recordset_signals[RECORDSET_ERROR] =
 		gtk_signal_new("error",
 		               GTK_RUN_LAST,
 		               object_class->type,
-		               GTK_SIGNAL_OFFSET(Gda_RecordsetClass, error),
+		               GTK_SIGNAL_OFFSET(GdaRecordsetClass, error),
 		               gtk_marshal_NONE__POINTER,
 		               GTK_TYPE_NONE,
 		               1,
@@ -138,21 +148,21 @@ gda_recordset_class_init (Gda_RecordsetClass *klass) {
 		gtk_signal_new("eof",
 		               GTK_RUN_LAST,
 		               object_class->type,
-		               GTK_SIGNAL_OFFSET(Gda_RecordsetClass, eof),
+		               GTK_SIGNAL_OFFSET(GdaRecordsetClass, eof),
 		               gtk_signal_default_marshaller,
 		               GTK_TYPE_NONE, 0);
 	gda_recordset_signals[RECORDSET_BOF] =
 		gtk_signal_new("bof",
 		               GTK_RUN_LAST,
 		               object_class->type,
-		               GTK_SIGNAL_OFFSET(Gda_RecordsetClass, bof),
+		               GTK_SIGNAL_OFFSET(GdaRecordsetClass, bof),
 		               gtk_signal_default_marshaller,
 		               GTK_TYPE_NONE, 0);
 	gda_recordset_signals[RECORDSET_ROW_CHANGED] =
 		gtk_signal_new("row_changed",
 		               GTK_RUN_LAST,
 		               object_class->type,
-		               GTK_SIGNAL_OFFSET(Gda_RecordsetClass, row_changed),
+		               GTK_SIGNAL_OFFSET(GdaRecordsetClass, row_changed),
 		               gtk_signal_default_marshaller,
 		               GTK_TYPE_NONE, 0);
 
@@ -162,14 +172,16 @@ gda_recordset_class_init (Gda_RecordsetClass *klass) {
 	klass->eof = NULL;
 	klass->bof = NULL;
 	klass->row_changed = NULL;
+	object_class->destroy = gda_recordset_destroy;
 }
 #endif
 
 static void
 #ifdef HAVE_GOBJECT
-gda_recordset_init (Gda_Recordset *rs, Gda_RecordsetClass *klass) {
+gda_recordset_init (GdaRecordset *rs, GdaRecordsetClass *klass)
+{
 #else
-gda_recordset_init (Gda_Recordset *rs) {
+gda_recordset_init (GdaRecordset *rs) {
 #endif
 	rs->external_cmd     = 0;
 	rs->internal_cmd     = 0;
@@ -192,8 +204,30 @@ gda_recordset_init (Gda_Recordset *rs) {
 	rs->name             = 0;
 }
 
+#ifndef HAVE_GOBJECT
 static void
-free_chunks (GList* chunks) {
+gda_recordset_destroy (GtkObject *object, gpointer user_data)
+{
+	GdaRecordset *rs = (GdaRecordset *) object;
+	GtkObjectClass *parent_class;
+
+	g_return_if_fail(IS_GDA_RECORDSET(rs));
+
+	if (rs->open)
+		gda_recordset_close(rs);
+	if (rs->internal_cmd) {
+		gda_command_free(rs->internal_cmd);
+	}
+
+	parent_class = gtk_type_class(gtk_object_get_type());
+	if (parent_class && parent_class->destroy)
+		parent_class->destroy(object);
+}
+#endif
+
+static void
+free_chunks (GList* chunks)
+{
 	GDA_Row* row;
 	GList*   ptr;
 	
@@ -206,7 +240,8 @@ free_chunks (GList* chunks) {
 }
 
 static GDA_Row*
-row_by_idx (Gda_Recordset* rs, gint idx) {
+row_by_idx (GdaRecordset* rs, gint idx)
+{
 	GDA_Recordset_Chunk* chunk;
 	
 	if (idx <= 0 || idx > g_list_length(rs->chunks))
@@ -223,8 +258,9 @@ row_by_idx (Gda_Recordset* rs, gint idx) {
  *
  * Returns: the allocated recordset object
  */
-Gda_Recordset *
-gda_recordset_new (void) {
+GdaRecordset *
+gda_recordset_new (void)
+{
 #ifdef HAVE_GOBJECT
 	return GDA_RECORDSET (g_object_new (GDA_TYPE_RECORDSET, NULL));
 #else
@@ -241,18 +277,14 @@ gda_recordset_new (void) {
  *
  */
 void
-gda_recordset_free (Gda_Recordset* rs) {
+gda_recordset_free (GdaRecordset* rs)
+{
 	g_return_if_fail(IS_GDA_RECORDSET(rs));
-	
-	if (rs->open)
-		gda_recordset_close(rs);
-	if (rs->internal_cmd) {
-		gda_command_free(rs->internal_cmd);
-	}
+
 #ifdef HAVE_GOBJECT
 	g_object_unref (G_OBJECT (rs));
 #else
-	gtk_object_destroy (GTK_OBJECT (rs));
+	gtk_object_unref (GTK_OBJECT (rs));
 #endif
 }
 
@@ -269,7 +301,8 @@ gda_recordset_free (Gda_Recordset* rs) {
  *
  */
 void
-gda_recordset_close (Gda_Recordset* rs) {
+gda_recordset_close (GdaRecordset* rs)
+{
 	CORBA_Environment ev;
 	
 	g_return_if_fail(IS_GDA_RECORDSET(rs));
@@ -302,7 +335,8 @@ gda_recordset_close (Gda_Recordset* rs) {
  * recordset is empty, FALSE otherwise.
  */
 gboolean
-gda_recordset_bof(Gda_Recordset* rs) {
+gda_recordset_bof(GdaRecordset* rs)
+{
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), 0);
 	
 	if (!rs->open || !rs->current_row || rs->bof)
@@ -323,7 +357,8 @@ gda_recordset_bof(Gda_Recordset* rs) {
  * recordset is empty, FALSE otherwise.
  */
 gboolean
-gda_recordset_eof (Gda_Recordset* rs) {
+gda_recordset_eof (GdaRecordset* rs)
+{
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), 0);
 	
 	if (!rs->open || rs->eof)
@@ -332,7 +367,8 @@ gda_recordset_eof (Gda_Recordset* rs) {
 }
 
 static gulong
-fetch_and_store(Gda_Recordset* rs, gint count, gpointer bookmark) {
+fetch_and_store(GdaRecordset* rs, gint count, gpointer bookmark)
+{
 	GDA_Recordset_Chunk* chunk;
 	gulong               current_idx;
 	CORBA_Environment    ev;
@@ -387,7 +423,8 @@ fetch_and_store(Gda_Recordset* rs, gint count, gpointer bookmark) {
 }
   
 static gulong
-fetch_and_dont_store(Gda_Recordset* rs, gint count, gpointer bookmark) {
+fetch_and_dont_store(GdaRecordset* rs, gint count, gpointer bookmark)
+{
 	GDA_Recordset_Chunk* chunk;
 	gulong               current_idx;
 	CORBA_Environment    ev;
@@ -458,7 +495,8 @@ fetch_and_dont_store(Gda_Recordset* rs, gint count, gpointer bookmark) {
  * fetching the rows.  
  */
 gulong
-gda_recordset_move (Gda_Recordset* rs, gint count, gpointer bookmark) {
+gda_recordset_move (GdaRecordset* rs, gint count, gpointer bookmark)
+{
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), GDA_RECORDSET_INVALID_POSITION);
 	g_return_val_if_fail(rs->corba_rs != NULL, GDA_RECORDSET_INVALID_POSITION);
 	g_return_val_if_fail(rs->open, GDA_RECORDSET_INVALID_POSITION);
@@ -474,7 +512,9 @@ gda_recordset_move (Gda_Recordset* rs, gint count, gpointer bookmark) {
 	else fetch_and_dont_store(rs, count, 0);
 	
 	/* emit "row_changed" signal for data-bound widgets */
+#ifndef HAVE_GOBJECT   /* FIXME */
 	gtk_signal_emit(GTK_OBJECT(rs), gda_recordset_signals[RECORDSET_ROW_CHANGED]);
+#endif
 	return rs->current_index;
 }
 
@@ -491,7 +531,8 @@ gda_recordset_move (Gda_Recordset* rs, gint count, gpointer bookmark) {
  * if there was an error. 
  */
 gulong
-gda_recordset_move_first (Gda_Recordset* rs) {
+gda_recordset_move_first (GdaRecordset* rs)
+{
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), GDA_RECORDSET_INVALID_POSITION);
 	
 	if (rs->cursor_location == GDA_USE_CLIENT_CURSOR) {
@@ -521,7 +562,8 @@ gda_recordset_move_first (Gda_Recordset* rs) {
  * if there was an error. 
  */
 gulong
-gda_recordset_move_last (Gda_Recordset* rs) {
+gda_recordset_move_last (GdaRecordset* rs)
+{
 	gulong pos;
 	gulong rc;
 	
@@ -556,7 +598,8 @@ gda_recordset_move_last (Gda_Recordset* rs) {
  * if there was an error. 
  */
 gulong
-gda_recordset_move_next (Gda_Recordset* rs) {
+gda_recordset_move_next (GdaRecordset* rs)
+{
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), GDA_RECORDSET_INVALID_POSITION);
 	return gda_recordset_move(rs, 1, 0);
 }
@@ -566,7 +609,8 @@ gda_recordset_move_next (Gda_Recordset* rs) {
  * @rs: the recordset
  */
 gulong
-gda_recordset_move_prev (Gda_Recordset *rs) {
+gda_recordset_move_prev (GdaRecordset *rs)
+{
 	return -1;
 }
 
@@ -581,10 +625,11 @@ gda_recordset_move_prev (Gda_Recordset *rs) {
  * Returns: a pointer to a field structor or NULL if 
  * @idx is out of range
  */
-Gda_Field*
-gda_recordset_field_idx (Gda_Recordset* rs, gint idx) {
+GdaField*
+gda_recordset_field_idx (GdaRecordset* rs, gint idx)
+{
 	gint       rowsize;
-	Gda_Field* rc;
+	GdaField* rc;
 	
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), 0);
 	g_return_val_if_fail(idx >= 0, 0);
@@ -618,8 +663,9 @@ gda_recordset_field_idx (Gda_Recordset* rs, gint idx) {
  * Returns: a pointer to a field structor or NULL if 
  * @idx is out of range
  */
-Gda_Field *
-gda_recordset_field_name (Gda_Recordset* rs, gchar* name) {
+GdaField *
+gda_recordset_field_name (GdaRecordset* rs, gchar* name)
+{
 	gint rowsize;
 	gint idx;
 	
@@ -645,7 +691,8 @@ gda_recordset_field_name (Gda_Recordset* rs, gchar* name) {
  * Returns the number of fields in a row of the current recordset
  */
 gint
-gda_recordset_rowsize (Gda_Recordset* rs) {
+gda_recordset_rowsize (GdaRecordset* rs)
+{
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), -1);
 	g_return_val_if_fail(rs->open, -1);
 	
@@ -663,7 +710,8 @@ gda_recordset_rowsize (Gda_Recordset* rs) {
  * Return the number of affected rows in the recordset
  */
 gulong
-gda_recordset_affected_rows (Gda_Recordset *rs) {
+gda_recordset_affected_rows (GdaRecordset *rs)
+{
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), 0);
 	return rs->affected_rows;
 }
@@ -682,7 +730,8 @@ gda_recordset_affected_rows (Gda_Recordset *rs) {
  * Returns: 0 if everyhting is okay, -1 on error
  */
 gint
-gda_recordset_set_connection (Gda_Recordset* rs, Gda_Connection* cnc) {
+gda_recordset_set_connection (GdaRecordset* rs, GdaConnection* cnc)
+{
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), -1);
 	
 	if (rs->open) return -1;
@@ -698,8 +747,9 @@ gda_recordset_set_connection (Gda_Recordset* rs, Gda_Connection* cnc) {
  * the recordset isn't open or there's no connection assoctiated with
  * this recordset.
  */
-Gda_Connection*
-gda_recordset_get_connection (Gda_Recordset* rs) {
+GdaConnection*
+gda_recordset_get_connection (GdaRecordset* rs)
+{
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), NULL);
 	
 	if (!rs->open)
@@ -726,11 +776,12 @@ gda_recordset_get_connection (Gda_Recordset* rs) {
  * Returns: 0 if everytrhing is okay, -1 on error
  */
 gint
-gda_recordset_open (Gda_Recordset* rs,
-                    Gda_Command* cmd,
+gda_recordset_open (GdaRecordset* rs,
+                    GdaCommand* cmd,
                     GDA_CursorType cursor_type,
                     GDA_LockType lock_type,
-                    gulong options) {
+                    gulong options)
+{
 	CORBA_Environment    ev;
 	GDA_CmdParameterSeq* corba_parameters;
 	CORBA_long           affected = 0;
@@ -794,13 +845,14 @@ gda_recordset_open (Gda_Recordset* rs,
  * Returns: 0 if everytrhing is okay, -1 on error
  */
 gint
-gda_recordset_open_txt (Gda_Recordset* rs,
+gda_recordset_open_txt (GdaRecordset* rs,
                         gchar* txt,
                         GDA_CursorType cursor_type,
                         GDA_LockType lock_type,
-                        gulong options) {
+                        gulong options)
+{
 	CORBA_Environment  ev;
-	Gda_Command*       cmd;
+	GdaCommand*       cmd;
 	gint               rc;
 	
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), -1);
@@ -822,7 +874,8 @@ gda_recordset_open_txt (Gda_Recordset* rs,
  * gda_recordset_add_field
  */
 gint
-gda_recordset_add_field (Gda_Recordset* rs, Gda_Field* field) {
+gda_recordset_add_field (GdaRecordset* rs, GdaField* field)
+{
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), -1);
 	g_return_val_if_fail(IS_GDA_FIELD(field), -1);
 	g_return_val_if_fail(field->attributes, -1);
@@ -861,7 +914,8 @@ gda_recordset_add_field (Gda_Recordset* rs, Gda_Field* field) {
  * Returns: the current value of the cursor location attribute
  */
 GDA_CursorLocation
-gda_recordset_get_cursorloc (Gda_Recordset* rs) {
+gda_recordset_get_cursorloc (GdaRecordset* rs)
+{
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), -1);
 	return rs->cursor_location;
 }
@@ -875,7 +929,8 @@ gda_recordset_get_cursorloc (Gda_Recordset* rs) {
  */
 
 void
-gda_recordset_set_cursorloc(Gda_Recordset* rs, GDA_CursorLocation loc) {
+gda_recordset_set_cursorloc(GdaRecordset* rs, GDA_CursorLocation loc)
+{
 	g_return_if_fail(IS_GDA_RECORDSET(rs));
 	rs->cursor_location = loc;
 }
@@ -887,7 +942,8 @@ gda_recordset_set_cursorloc(Gda_Recordset* rs, GDA_CursorLocation loc) {
  * Returns: the current value of the cursor type attriburte
  */
 GDA_CursorType
-gda_recordset_get_cursortype(Gda_Recordset* rs) {
+gda_recordset_get_cursortype(GdaRecordset* rs)
+{
 	g_return_val_if_fail(IS_GDA_RECORDSET(rs), -1);
 	return rs->cursor_type;
 }
@@ -900,7 +956,8 @@ gda_recordset_get_cursortype(Gda_Recordset* rs) {
  * Set the cursor type attribute to @type.
  */
 void
-gda_recordset_set_cursortype(Gda_Recordset* rs, GDA_CursorType type) {
+gda_recordset_set_cursortype(GdaRecordset* rs, GDA_CursorType type)
+{
 	g_return_if_fail(IS_GDA_RECORDSET(rs));
 	rs->cursor_type = type;
 }
