@@ -20,7 +20,7 @@
 #include <ctype.h>
 
 gboolean
-gda_ldap_connection_new (Gda_ServerConnection *cnc)
+gda_ldap_connection_new (GdaServerConnection *cnc)
 {
   LDAP_Connection* ld_cnc;
 
@@ -46,13 +46,13 @@ get_value (gchar* ptr)
 }
 
 gint
-gda_ldap_connection_open (Gda_ServerConnection *cnc,
+gda_ldap_connection_open (GdaServerConnection *cnc,
 			  const gchar *dsn,
 			  const gchar *user,
 			  const gchar *password)
 {
   LDAP_Connection*     ld_cnc;
-  Gda_ServerError* error;
+  GdaServerError* error;
   gchar*               ptr_s;
   gchar*               ptr_e;
 
@@ -115,7 +115,7 @@ gda_ldap_connection_open (Gda_ServerConnection *cnc,
 }
 
 void
-gda_ldap_connection_close (Gda_ServerConnection *cnc)
+gda_ldap_connection_close (GdaServerConnection *cnc)
 {
   LDAP_Connection* ld_cnc;
 
@@ -130,7 +130,7 @@ gda_ldap_connection_close (Gda_ServerConnection *cnc)
 }
 
 gint
-gda_ldap_connection_begin_transaction (Gda_ServerConnection *cnc)
+gda_ldap_connection_begin_transaction (GdaServerConnection *cnc)
 {
   LDAP_Connection* ld_cnc;
 
@@ -144,7 +144,7 @@ gda_ldap_connection_begin_transaction (Gda_ServerConnection *cnc)
 }
 
 gint
-gda_ldap_connection_commit_transaction (Gda_ServerConnection *cnc)
+gda_ldap_connection_commit_transaction (GdaServerConnection *cnc)
 {
   LDAP_Connection* ld_cnc;
 
@@ -158,7 +158,7 @@ gda_ldap_connection_commit_transaction (Gda_ServerConnection *cnc)
 }
 
 gint
-gda_ldap_connection_rollback_transaction (Gda_ServerConnection *cnc)
+gda_ldap_connection_rollback_transaction (GdaServerConnection *cnc)
 {
   LDAP_Connection* ld_cnc;
 
@@ -171,9 +171,9 @@ gda_ldap_connection_rollback_transaction (Gda_ServerConnection *cnc)
   return -1;
 }
 
-Gda_ServerRecordset *
-gda_ldap_connection_open_schema (Gda_ServerConnection *cnc,
-				 Gda_ServerError *error,
+GdaServerRecordset *
+gda_ldap_connection_open_schema (GdaServerConnection *cnc,
+				 GdaServerError *error,
 				 GDA_Connection_QType t,
 				 GDA_Connection_Constraint *constraints,
 				 gint length)
@@ -182,7 +182,7 @@ gda_ldap_connection_open_schema (Gda_ServerConnection *cnc,
 }
 
 glong
-gda_ldap_connection_modify_schema (Gda_ServerConnection *cnc,
+gda_ldap_connection_modify_schema (GdaServerConnection *cnc,
                                    GDA_Connection_QType t,
                                    GDA_Connection_Constraint *constraints,
                                    gint length)
@@ -191,27 +191,27 @@ gda_ldap_connection_modify_schema (Gda_ServerConnection *cnc,
 }
 
 gint
-gda_ldap_connection_start_logging (Gda_ServerConnection *cnc,
+gda_ldap_connection_start_logging (GdaServerConnection *cnc,
 				   const gchar *filename)
 {
   return -1;
 }
 
 gint
-gda_ldap_connection_stop_logging (Gda_ServerConnection *cnc)
+gda_ldap_connection_stop_logging (GdaServerConnection *cnc)
 {
   return -1;
 }
 
 gchar *
-gda_ldap_connection_create_table (Gda_ServerConnection *cnc,
+gda_ldap_connection_create_table (GdaServerConnection *cnc,
 				       GDA_RowAttributes *columns)
 {
   return NULL;
 }
 
 gboolean
-gda_ldap_connection_supports (Gda_ServerConnection *cnc,
+gda_ldap_connection_supports (GdaServerConnection *cnc,
 				   GDA_Connection_Feature feature)
 {
   g_return_val_if_fail(cnc != NULL, FALSE);
@@ -221,7 +221,7 @@ gda_ldap_connection_supports (Gda_ServerConnection *cnc,
 }
 
 GDA_ValueType
-gda_ldap_connection_get_gda_type (Gda_ServerConnection *cnc, gulong sql_type)
+gda_ldap_connection_get_gda_type (GdaServerConnection *cnc, gulong sql_type)
 {
   g_return_val_if_fail(cnc != NULL, GDA_TypeNull);
 
@@ -232,7 +232,7 @@ gda_ldap_connection_get_gda_type (Gda_ServerConnection *cnc, gulong sql_type)
 }
 
 gshort
-gda_ldap_connection_get_c_type (Gda_ServerConnection *cnc, GDA_ValueType type)
+gda_ldap_connection_get_c_type (GdaServerConnection *cnc, GDA_ValueType type)
 {
   g_return_val_if_fail(cnc != NULL, -1);
 
@@ -242,8 +242,20 @@ gda_ldap_connection_get_c_type (Gda_ServerConnection *cnc, GDA_ValueType type)
   return -1;
 }
 
+gchar *
+gda_ldap_connection_sql2xml (GdaServerConnection *cnc, const gchar *sql)
+{
+  return NULL;
+}
+
+gchar *
+gda_ldap_connection_xml2sql (GdaServerConnection *cnc, const gchar *xml)
+{
+  return NULL;
+}
+
 void
-gda_ldap_connection_free (Gda_ServerConnection *cnc)
+gda_ldap_connection_free (GdaServerConnection *cnc)
 {
   LDAP_Connection* ld_cnc;
 
@@ -257,9 +269,9 @@ gda_ldap_connection_free (Gda_ServerConnection *cnc)
 }
 
 void
-gda_ldap_error_make (Gda_ServerError *error,
-		     Gda_ServerRecordset *recset,
-		     Gda_ServerConnection *cnc,
+gda_ldap_error_make (GdaServerError *error,
+		     GdaServerRecordset *recset,
+		     GdaServerConnection *cnc,
 		     gchar *where)
 {
   gchar*           err_msg;
