@@ -18,8 +18,8 @@
 
 #include "gda-ldap.h"
 
-static Gda_ServerImpl*         server_impl = NULL;
-static Gda_ServerImplFunctions server_impl_functions =
+static GdaServerImpl*         server_impl = NULL;
+static GdaServerImplFunctions server_impl_functions =
 {
   gda_ldap_connection_new,
   gda_ldap_connection_open,
@@ -35,6 +35,8 @@ static Gda_ServerImplFunctions server_impl_functions =
   gda_ldap_connection_supports,
   gda_ldap_connection_get_gda_type,
   gda_ldap_connection_get_c_type,
+  gda_ldap_connection_sql2xml,
+  gda_ldap_connection_xml2sql,
   gda_ldap_connection_free,
 
   gda_ldap_command_new,
