@@ -19,25 +19,25 @@
 
 #include "gda-oracle.h"
 
-typedef Gda_ServerRecordset* (*schema_ops_fn)(Gda_ServerError *,
-					      Gda_ServerConnection *,
+typedef GdaServerRecordset* (*schema_ops_fn)(GdaServerError *,
+					      GdaServerConnection *,
 					      GDA_Connection_Constraint *constraints,
 					      gint length);
 
-static Gda_ServerRecordset* schema_columns (Gda_ServerError *error,
-					    Gda_ServerConnection *cnc,
+static GdaServerRecordset* schema_columns (GdaServerError *error,
+					    GdaServerConnection *cnc,
 					    GDA_Connection_Constraint *constraints,
 					    gint length);
-static Gda_ServerRecordset* schema_procedures (Gda_ServerError *error,
-					       Gda_ServerConnection *cnc,
+static GdaServerRecordset* schema_procedures (GdaServerError *error,
+					       GdaServerConnection *cnc,
 					       GDA_Connection_Constraint *constraints,
 					       gint length);
-static Gda_ServerRecordset* schema_tables (Gda_ServerError *error,
-					   Gda_ServerConnection *cnc,
+static GdaServerRecordset* schema_tables (GdaServerError *error,
+					   GdaServerConnection *cnc,
 					   GDA_Connection_Constraint *constraints,
 					   gint length);
-static Gda_ServerRecordset* schema_views (Gda_ServerError *error,
-					  Gda_ServerConnection *cnc,
+static GdaServerRecordset* schema_views (GdaServerError *error,
+					  GdaServerConnection *cnc,
 					  GDA_Connection_Constraint *constraints,
 					  gint length);
 
@@ -62,7 +62,7 @@ initialize_schema_ops (void)
  * Public functions
  */
 gboolean
-gda_oracle_connection_new (Gda_ServerConnection *cnc)
+gda_oracle_connection_new (GdaServerConnection *cnc)
 {
   static gboolean    initialized;
   ORACLE_Connection* ora_cnc;
@@ -125,13 +125,13 @@ gda_oracle_connection_new (Gda_ServerConnection *cnc)
 }
 
 gint
-gda_oracle_connection_open (Gda_ServerConnection *cnc,
+gda_oracle_connection_open (GdaServerConnection *cnc,
 			    const gchar *dsn,
 			    const gchar *user,
 			    const gchar *password)
 {
   ORACLE_Connection* ora_cnc;
-  Gda_ServerError*   error;
+  GdaServerError*   error;
 
   g_return_val_if_fail(cnc != NULL, -1);
 
@@ -195,7 +195,7 @@ gda_oracle_connection_open (Gda_ServerConnection *cnc,
 }
 
 void
-gda_oracle_connection_close (Gda_ServerConnection *cnc)
+gda_oracle_connection_close (GdaServerConnection *cnc)
 {
   ORACLE_Connection* ora_cnc;
 
@@ -221,7 +221,7 @@ gda_oracle_connection_close (Gda_ServerConnection *cnc)
 }
 
 gint
-gda_oracle_connection_begin_transaction (Gda_ServerConnection *cnc)
+gda_oracle_connection_begin_transaction (GdaServerConnection *cnc)
 {
   ORACLE_Connection* ora_cnc;
 
@@ -241,7 +241,7 @@ gda_oracle_connection_begin_transaction (Gda_ServerConnection *cnc)
 }
 
 gint
-gda_oracle_connection_commit_transaction (Gda_ServerConnection *cnc)
+gda_oracle_connection_commit_transaction (GdaServerConnection *cnc)
 {
   ORACLE_Connection* ora_cnc;
 
@@ -260,7 +260,7 @@ gda_oracle_connection_commit_transaction (Gda_ServerConnection *cnc)
 }
 
 gint
-gda_oracle_connection_rollback_transaction (Gda_ServerConnection *cnc)
+gda_oracle_connection_rollback_transaction (GdaServerConnection *cnc)
 {
   ORACLE_Connection* ora_cnc;
 
@@ -278,9 +278,9 @@ gda_oracle_connection_rollback_transaction (Gda_ServerConnection *cnc)
   return -1;
 }
 
-Gda_ServerRecordset *
-gda_oracle_connection_open_schema (Gda_ServerConnection *cnc,
-				   Gda_ServerError *error,
+GdaServerRecordset *
+gda_oracle_connection_open_schema (GdaServerConnection *cnc,
+				   GdaServerError *error,
 				   GDA_Connection_QType t,
 				   GDA_Connection_Constraint *constraints,
 				   gint length)
@@ -297,7 +297,7 @@ gda_oracle_connection_open_schema (Gda_ServerConnection *cnc,
 }
 
 glong
-gda_oracle_connection_modify_schema (Gda_ServerConnection *cnc,
+gda_oracle_connection_modify_schema (GdaServerConnection *cnc,
                                    GDA_Connection_QType t,
                                    GDA_Connection_Constraint *constraints,
                                    gint length)
@@ -306,27 +306,27 @@ gda_oracle_connection_modify_schema (Gda_ServerConnection *cnc,
 }
 
 gint
-gda_oracle_connection_start_logging (Gda_ServerConnection *cnc,
+gda_oracle_connection_start_logging (GdaServerConnection *cnc,
 				   const gchar *filename)
 {
   return -1;
 }
 
 gint
-gda_oracle_connection_stop_logging (Gda_ServerConnection *cnc)
+gda_oracle_connection_stop_logging (GdaServerConnection *cnc)
 {
   return -1;
 }
 
 gchar *
-gda_oracle_connection_create_table (Gda_ServerConnection *cnc,
+gda_oracle_connection_create_table (GdaServerConnection *cnc,
 				       GDA_RowAttributes *columns)
 {
   return NULL;
 }
 
 gboolean
-gda_oracle_connection_supports (Gda_ServerConnection *cnc,
+gda_oracle_connection_supports (GdaServerConnection *cnc,
 				GDA_Connection_Feature feature)
 {
   g_return_val_if_fail(cnc != NULL, FALSE);
@@ -347,7 +347,7 @@ gda_oracle_connection_supports (Gda_ServerConnection *cnc,
 }
 
 GDA_ValueType
-gda_oracle_connection_get_gda_type (Gda_ServerConnection *cnc, gulong sql_type)
+gda_oracle_connection_get_gda_type (GdaServerConnection *cnc, gulong sql_type)
 {
   g_return_val_if_fail(cnc != NULL, GDA_TypeNull);
 
@@ -382,7 +382,7 @@ gda_oracle_connection_get_gda_type (Gda_ServerConnection *cnc, gulong sql_type)
 }
 
 gshort
-gda_oracle_connection_get_c_type (Gda_ServerConnection *cnc, GDA_ValueType type)
+gda_oracle_connection_get_c_type (GdaServerConnection *cnc, GDA_ValueType type)
 {
   g_return_val_if_fail(cnc != NULL, -1);
 
@@ -392,8 +392,20 @@ gda_oracle_connection_get_c_type (Gda_ServerConnection *cnc, GDA_ValueType type)
   return -1;
 }
 
+gchar *
+gda_oracle_connection_sql2xml (GdaServerConnection *cnc, const gchar *sql)
+{
+  return NULL;
+}
+
+gchar *
+gda_oracle_connection_xml2sql (GdaServerConnection *cnc, const gchar *xml)
+{
+  return NULL;
+}
+
 void
-gda_oracle_connection_free (Gda_ServerConnection *cnc)
+gda_oracle_connection_free (GdaServerConnection *cnc)
 {
   ORACLE_Connection* ora_cnc;
 
@@ -407,9 +419,9 @@ gda_oracle_connection_free (Gda_ServerConnection *cnc)
 }
 
 void
-gda_oracle_error_make (Gda_ServerError *error,
-		     Gda_ServerRecordset *recset,
-		     Gda_ServerConnection *cnc,
+gda_oracle_error_make (GdaServerError *error,
+		     GdaServerRecordset *recset,
+		     GdaServerConnection *cnc,
 		     gchar *where)
 {
   ORACLE_Connection* ora_cnc;
@@ -435,15 +447,15 @@ gda_oracle_error_make (Gda_ServerError *error,
     }
 }
 
-static Gda_ServerRecordset *
-schema_columns (Gda_ServerError *error,
-		Gda_ServerConnection *cnc,
+static GdaServerRecordset *
+schema_columns (GdaServerError *error,
+		GdaServerConnection *cnc,
 		GDA_Connection_Constraint *constraint,
 		gint length)
 {
   gchar*                      query = NULL;
   gchar*                      name = NULL;
-  Gda_ServerCommand*          cmd = NULL;
+  GdaServerCommand*          cmd = NULL;
   GDA_Connection_Constraint*  ptr = NULL;
   gint                        cnt;
 
@@ -483,15 +495,15 @@ schema_columns (Gda_ServerError *error,
   return gda_server_command_execute(cmd, error, NULL, NULL, 0);
 }
 
-static Gda_ServerRecordset *
-schema_procedures (Gda_ServerError *error,
-		   Gda_ServerConnection *cnc,
+static GdaServerRecordset *
+schema_procedures (GdaServerError *error,
+		   GdaServerConnection *cnc,
 		   GDA_Connection_Constraint *constraints,
 		   gint length)
 {
   gchar*                      query = NULL;
   gchar*                      name = NULL;
-  Gda_ServerCommand*          cmd = NULL;
+  GdaServerCommand*          cmd = NULL;
   GDA_Connection_Constraint*  ptr = NULL;
   gboolean                    extra_info = FALSE;
   gint                        cnt;
@@ -553,9 +565,9 @@ schema_procedures (Gda_ServerError *error,
   return gda_server_command_execute(cmd, error, NULL, NULL, 0);
 }
 
-static Gda_ServerRecordset *
-schema_tables (Gda_ServerError *error,
-	       Gda_ServerConnection *cnc,
+static GdaServerRecordset *
+schema_tables (GdaServerError *error,
+	       GdaServerConnection *cnc,
 	       GDA_Connection_Constraint *constraints,
 	       gint length)
 {
@@ -563,7 +575,7 @@ schema_tables (Gda_ServerError *error,
   gchar*                      name = NULL;
   gchar*                      schema = NULL;
   GString*                    where_clause = NULL;
-  Gda_ServerCommand*          cmd = NULL;
+  GdaServerCommand*          cmd = NULL;
   GDA_Connection_Constraint*  ptr = NULL;
   gboolean                    extra_info = FALSE;
   gint                        cnt;
@@ -636,9 +648,9 @@ schema_tables (Gda_ServerError *error,
   return gda_server_command_execute(cmd, error, NULL, NULL, 0);
 }
 
-static Gda_ServerRecordset *
-schema_views (Gda_ServerError *error,
-	      Gda_ServerConnection *cnc,
+static GdaServerRecordset *
+schema_views (GdaServerError *error,
+	      GdaServerConnection *cnc,
 	      GDA_Connection_Constraint *constraints,
 	      gint length)
 {
@@ -646,7 +658,7 @@ schema_views (Gda_ServerError *error,
   gchar*                      name = NULL;
   gchar*                      schema = NULL;
   GString*                    where_clause = NULL;
-  Gda_ServerCommand*          cmd = NULL;
+  GdaServerCommand*          cmd = NULL;
   GDA_Connection_Constraint*  ptr = NULL;
   gboolean                    extra_info = FALSE;
   gint                        cnt;
