@@ -1,5 +1,5 @@
 /*
- * $Id: gda-sybase-command.c,v 1.3 2000/10/29 17:55:29 holger Exp $
+ * $Id: gda-sybase-command.c,v 1.5 2001/04/07 08:49:31 rodrigo Exp $
  *
  * GNOME DB sybase Provider
  * Copyright (C) 2000 Holger Thon
@@ -22,6 +22,18 @@
  */
 
 // $Log: gda-sybase-command.c,v $
+// Revision 1.5  2001/04/07 08:49:31  rodrigo
+// 2001-04-07  Rodrigo Moya <rodrigo@gnome-db.org>
+//
+// 	* objects renaming (Gda_* to Gda*) to conform to the GNOME
+// 	naming standards
+//
+// Revision 1.4  2001/03/08 17:56:15  holger
+// Holger Thon <holger.thon@gnome-db.org>  Mar 8th, 2001
+//
+// 	* Added debian packaging proto entries for gda-primebase, gda-sybase,
+// 	  gda-tds
+//
 // Revision 1.3  2000/10/29 17:55:29  holger
 // - fixed AUTHORS file
 // - no code changes to gda-sybase-command.c (timestamp failure)
@@ -48,9 +60,9 @@
  * Public functions
  */
 gboolean
-gda_sybase_command_new (Gda_ServerCommand *cmd)
+gda_sybase_command_new (GdaServerCommand *cmd)
 {
-  Gda_ServerConnection *cnc = NULL;
+  GdaServerConnection *cnc = NULL;
   sybase_Command       *scmd = NULL;
   sybase_Connection    *scnc = NULL;
 
@@ -82,15 +94,15 @@ gda_sybase_command_new (Gda_ServerCommand *cmd)
   return TRUE;
 }
 
-Gda_ServerRecordset *
-gda_sybase_command_execute (Gda_ServerCommand *cmd,
-                            Gda_ServerError *error,
+GdaServerRecordset *
+gda_sybase_command_execute (GdaServerCommand *cmd,
+                            GdaServerError *error,
                             const GDA_CmdParameterSeq *params,
                             gulong *affected,
                             gulong options)
 {
-  Gda_ServerConnection* cnc = NULL;
-  Gda_ServerRecordset*  recset = NULL;
+  GdaServerConnection* cnc = NULL;
+  GdaServerRecordset*  recset = NULL;
   sybase_Connection*    scnc = NULL;
   sybase_Command*       scmd = NULL;
   sybase_Recordset*     srecset = NULL;
@@ -111,7 +123,7 @@ gda_sybase_command_execute (Gda_ServerCommand *cmd,
 
   if (gda_sybase_connection_dead(cnc))
     {
-      //             gda_server_error_make(error, 0, cnc, "connection seems to be dead");
+//      gda_server_error_make(error, 0, cnc, "connection seems to be dead");
       gda_log_error(_("Connection seems to be dead"));
       sybase_chkerr(error, NULL, cnc, cmd, __PRETTY_FUNCTION__);
     }
@@ -122,11 +134,10 @@ gda_sybase_command_execute (Gda_ServerCommand *cmd,
 
   // Initialize cmd structure and send query
   if (SYB_CHK((CS_INT *) &scnc->ret,
-	      ct_command(scmd->cmd, CS_LANG_CMD, sql_cmd, CS_NULLTERM,
-			 CS_UNUSED
-			 ),
-	      error, NULL, cnc, cmd
-	      ) != CS_SUCCEED)
+              ct_command(scmd->cmd, CS_LANG_CMD, sql_cmd, CS_NULLTERM,
+                         CS_UNUSED),
+              error, NULL, cnc, cmd
+ 	          ) != CS_SUCCEED)
     {
       // Cancel command if setting cmd structure fails
       SYB_CHK((CS_INT *) &scnc->ret, ct_cancel(NULL, scmd->cmd, CS_CANCEL_ALL),
@@ -287,9 +298,9 @@ gda_sybase_command_execute (Gda_ServerCommand *cmd,
 }
 
 void
-gda_sybase_command_free (Gda_ServerCommand *cmd)
+gda_sybase_command_free (GdaServerCommand *cmd)
 {
-  Gda_ServerConnection *cnc = NULL;
+  GdaServerConnection *cnc = NULL;
   sybase_Connection    *scnc = NULL;
   sybase_Command       *scmd = NULL;
   
