@@ -1,5 +1,5 @@
 /* 
- * $Id: gda-sybase-connection.h,v 1.2 2000/11/27 17:50:27 rodrigo Exp $
+ * $Id: gda-sybase-connection.h,v 1.4 2001/04/07 08:49:31 rodrigo Exp $
  *
  * GNOME DB sybase Provider
  * Copyright (C) 2000 Rodrigo Moya
@@ -58,7 +58,7 @@ typedef struct _sybase_Connection {
   gboolean        cs_diag; // wether we can use cs_diag for cslib messages
   gboolean        ct_diag; // wether we can use ct_diag for ctlib messages
   
-  Gda_ServerError *error;
+  GdaServerError *error;
   sybase_Error    serr;
   
   gchar           *database;
@@ -67,39 +67,41 @@ typedef struct _sybase_Connection {
 /*
  * Server implementation prototypes
  */
-gboolean gda_sybase_connection_new (Gda_ServerConnection *cnc);
-gint gda_sybase_connection_open (Gda_ServerConnection *cnc, const gchar *dsn,
+gboolean gda_sybase_connection_new (GdaServerConnection *cnc);
+gint gda_sybase_connection_open (GdaServerConnection *cnc, const gchar *dsn,
                                  const gchar *user, const gchar *passwd);
-void gda_sybase_connection_close (Gda_ServerConnection *cnc);
-gint gda_sybase_connection_begin_transaction (Gda_ServerConnection *cnc);
-gint gda_sybase_connection_commit_transaction (Gda_ServerConnection *cnc);
-gint gda_sybase_connection_rollback_transaction (Gda_ServerConnection *cnc);
-Gda_ServerRecordset* gda_sybase_connection_open_schema (Gda_ServerConnection *cnc,
-							Gda_ServerError *error,
+void gda_sybase_connection_close (GdaServerConnection *cnc);
+gint gda_sybase_connection_begin_transaction (GdaServerConnection *cnc);
+gint gda_sybase_connection_commit_transaction (GdaServerConnection *cnc);
+gint gda_sybase_connection_rollback_transaction (GdaServerConnection *cnc);
+GdaServerRecordset* gda_sybase_connection_open_schema (GdaServerConnection *cnc,
+							GdaServerError *error,
 							GDA_Connection_QType t,
 							GDA_Connection_Constraint *constraints,
 							gint length);
-glong gda_sybase_connection_modify_schema (Gda_ServerConnection *cnc,
+glong gda_sybase_connection_modify_schema (GdaServerConnection *cnc,
                                    GDA_Connection_QType t,
                                    GDA_Connection_Constraint *constraints,
                                    gint length);
-gint gda_sybase_connection_start_logging (Gda_ServerConnection *cnc,
+gint gda_sybase_connection_start_logging (GdaServerConnection *cnc,
 					  const gchar *filename);
-gint gda_sybase_connection_stop_logging (Gda_ServerConnection *cnc);
-gchar* gda_sybase_connection_create_table (Gda_ServerConnection *cnc,
+gint gda_sybase_connection_stop_logging (GdaServerConnection *cnc);
+gchar* gda_sybase_connection_create_table (GdaServerConnection *cnc,
 					   GDA_RowAttributes *columns);
-gboolean gda_sybase_connection_supports(Gda_ServerConnection *,
+gboolean gda_sybase_connection_supports(GdaServerConnection *,
                                         GDA_Connection_Feature feature);
-const GDA_ValueType gda_sybase_connection_get_gda_type(Gda_ServerConnection *,
+const GDA_ValueType gda_sybase_connection_get_gda_type(GdaServerConnection *,
                                                        gulong);
-const gshort gda_sybase_connection_get_c_type(Gda_ServerConnection *,
+const gshort gda_sybase_connection_get_c_type(GdaServerConnection *,
                                               GDA_ValueType type);
-void gda_sybase_connection_free (Gda_ServerConnection *cnc);
-void gda_sybase_connection_clear_user_data(Gda_ServerConnection *, gboolean);
+gchar* gda_sybase_connection_sql2xml (GdaServerConnection *cnc, const gchar *sql);
+gchar* gda_sybase_connection_xml2sql (GdaServerConnection *cnc, const gchar *xml);
+void gda_sybase_connection_free (GdaServerConnection *cnc);
+void gda_sybase_connection_clear_user_data(GdaServerConnection *, gboolean);
 
-gboolean gda_sybase_connection_dead(Gda_ServerConnection *);
-gboolean gda_sybase_connection_reopen(Gda_ServerConnection *);
-CS_RETCODE gda_sybase_connection_select_database(Gda_ServerConnection *,
+gboolean gda_sybase_connection_dead(GdaServerConnection *);
+gboolean gda_sybase_connection_reopen(GdaServerConnection *);
+CS_RETCODE gda_sybase_connection_select_database(GdaServerConnection *,
                                                  const gchar * dbname);
 
 #endif
