@@ -1,5 +1,5 @@
 /* 
- * $Id: main-sybase.c,v 1.5 2000/12/18 15:32:14 rodrigo Exp $
+ * $Id: main-sybase.c,v 1.7 2001/04/07 08:49:31 rodrigo Exp $
  * 
  * GNOME DB sybase Provider
  * Copyright (C) 2000 Rodrigo Moya
@@ -23,8 +23,8 @@
 
 #include "gda-sybase.h"
 
-static Gda_ServerImpl*         server_impl = NULL;
-static Gda_ServerImplFunctions server_impl_functions =
+static GdaServerImpl*         server_impl = NULL;
+static GdaServerImplFunctions server_impl_functions =
 {
   gda_sybase_connection_new,
   gda_sybase_connection_open,
@@ -40,6 +40,8 @@ static Gda_ServerImplFunctions server_impl_functions =
   gda_sybase_connection_supports,
   gda_sybase_connection_get_gda_type,
   gda_sybase_connection_get_c_type,
+  gda_sybase_connection_sql2xml,
+  gda_sybase_connection_xml2sql,
   gda_sybase_connection_free,
 
   gda_sybase_command_new,
